spannertools.HairpinSpanner
===========================

.. abjad-lineage:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner

.. autoclass:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.append
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.append_left
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.attach
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.components
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.detach
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.direction
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.extend
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.extend_left
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.fracture
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.fuse
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.get_duration
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.get_timespan
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.include_rests
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.index
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.is_hairpin_shape_string
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.is_hairpin_token
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.leaves
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.override
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.pop
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.pop_left
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.set
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.shape_string
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.start_dynamic_string
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.stop_dynamic_string
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__call__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__contains__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__copy__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__eq__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__getitem__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__len__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__lt__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__ne__
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__repr__

Bases
-----

- :py:class:`spannertools.DirectedSpanner <abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.include_rests
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.shape_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.start_dynamic_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.stop_dynamic_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.is_hairpin_shape_string
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.is_hairpin_token
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner.__repr__
   :noindex:
